From 3b83905603d44b1a08f8b2b36a605808ce686ad6 Mon Sep 17 00:00:00 2001
From: Jake Vanderwerf <get@jakevanderwerf.ca>
Date: Tue, 02 Jun 2026 00:46:48 +0000
Subject: [PATCH] =double checking schema outputs for legacytattooremoval

---
 cleanup.php |   59 ++++++++++++++++++++++++++++++++++++++++++++++++++++++++---
 1 files changed, 56 insertions(+), 3 deletions(-)

diff --git a/cleanup.php b/cleanup.php
index 6444cb4..8aef5fa 100644
--- a/cleanup.php
+++ b/cleanup.php
@@ -27,12 +27,19 @@
 	// Remove global WordPress styles
 	$global_styles = [
 		'global-styles',
+		'classic-theme-styles',
+		'core-block-supports',
 		'dashicons',
-		'core-block-supports'
+		'common',
+		'wp-block-library',
+		'wp-block-library-theme',
+		'wp-block-styles',
+		'block-style-variation-styles'
 	];
 
 	foreach ($global_styles as $style) {
 		wp_dequeue_style($style);
+		wp_deregister_style($style);
 	}
 
 	// Remove all block-specific styles
@@ -40,6 +47,7 @@
 	foreach ($wp_styles->queue as $handle) {
 		if (str_starts_with($handle, 'wp-block-')) {
 			wp_dequeue_style($handle);
+			wp_deregister_style($style);
 		}
 	}
 
@@ -61,7 +69,7 @@
 	// Remove third-party styles
 	wp_deregister_style('akismet-widget-style-inline-css');
 }
-add_action('wp_enqueue_scripts', 'jvbRemoveBlockAssets', 999);
+add_action('wp_enqueue_scripts', 'jvbRemoveBlockAssets', 9999);
 
 /*******************************************************************************
 WORDPRESS HEAD CLEANUP
@@ -203,7 +211,7 @@
 		BASE . 'gallery'
 	];
 
 	//TODO: Dynamically use MetaManager to get any image or gallery fields
 	foreach ($meta_fields as $meta_key) {
 		$meta_value = get_post_meta($post_id, $meta_key, true);
 
@@ -256,3 +264,48 @@
 	return $clean_classes;
 }
 add_filter('body_class', 'jvbBodyClasses');
+
+
+add_action('admin_init', function () {
+	// Redirect any user trying to access comments page
+	global $pagenow;
+
+	if ($pagenow === 'edit-comments.php') {
+		wp_redirect(admin_url());
+		exit;
+	}
+
+	// Remove comments metabox from dashboard
+	remove_meta_box('dashboard_recent_comments', 'dashboard', 'normal');
+
+	// Disable support for comments and trackbacks in post types
+	foreach (get_post_types() as $post_type) {
+		if (post_type_supports($post_type, 'comments')) {
+			remove_post_type_support($post_type, 'comments');
+			remove_post_type_support($post_type, 'trackbacks');
+		}
+	}
+});
+
+// Close comments on the front-end
+add_filter('comments_open', '__return_false', 20, 2);
+add_filter('pings_open', '__return_false', 20, 2);
+
+// Hide existing comments
+add_filter('comments_array', '__return_empty_array', 10, 2);
+
+// Remove comments page in menu
+add_action('admin_menu', function () {
+	remove_menu_page('edit-comments.php');
+});
+
+// Remove comments links from admin bar
+add_action('init', function () {
+	if (is_admin_bar_showing()) {
+		remove_action('admin_bar_menu', 'wp_admin_bar_comments_menu', 60);
+	}
+});
+// Remove comments links from admin bar
+add_action('add_admin_bar_menus', function () {
+	remove_action('admin_bar_menu', 'wp_admin_bar_comments_menu', 60);
+});
@@ -203,7 +211,7 @@
 	];
 
-	//TODO: Dynamically use MetaManager to get any image or gallery fields
+	//TODO: Dynamically use Meta.php to get any image or gallery fields
 	foreach ($meta_fields as $meta_key) {
 		$meta_value = get_post_meta($post_id, $meta_key, true);

--
Gitblit v1.10.0